@@ -9,15 +9,11 @@ describe 'glance::api' do
 
   let :default_params do
     {
-      :debug                    => false,
-      :use_stderr               => '<SERVICE DEFAULT>',
       :bind_host                => '<SERVICE DEFAULT>',
       :bind_port                => '9292',
       :registry_host            => '0.0.0.0',
       :registry_port            => '<SERVICE DEFAULT>',
       :registry_client_protocol => '<SERVICE DEFAULT>',
-      :log_file                 => '/var/log/glance/api.log',
-      :log_dir                  => '/var/log/glance',
       :auth_strategy            => 'keystone',
       :enabled                  => true,
       :manage_service           => true,
@@ -25,12 +21,18 @@ describe 'glance::api' do
       :workers                  => '7',
       :show_image_direct_url    => '<SERVICE DEFAULT>',
       :show_multiple_locations  => '<SERVICE DEFAULT>',
+      :filesystem_store_metadata_file => '<SERVICE DEFAULT>',
+      :filesystem_store_file_perm => '<SERVICE DEFAULT>',
       :location_strategy        => '<SERVICE DEFAULT>',
       :purge_config             => false,
       :delayed_delete           => '<SERVICE DEFAULT>',
       :scrub_time               => '<SERVICE DEFAULT>',
       :default_store            => false,
       :image_cache_dir          => '/var/lib/glance/image-cache',
+      :image_import_plugins     => '<SERVICE DEFAULT>',
+      :image_conversion_output_format => '<SERVICE DEFAULT>',
+      :inject_metadata_properties => '<SERVICE DEFAULT>',
+      :ignore_user_roles        => '<SERVICE DEFAULT>',
       :enabled_import_methods   => '<SERVICE DEFAULT>',
       :node_staging_uri         => '<SERVICE DEFAULT>',
       :image_member_quota       => '<SERVICE DEFAULT>',
@@ -55,7 +57,6 @@ describe 'glance::api' do
   shared_examples_for 'glance::api' do
 
     [{
-        :debug                    => true,
         :bind_host                => '127.0.0.1',
         :bind_port                => '9222',
         :registry_host            => '127.0.0.1',
@@ -67,10 +68,16 @@ describe 'glance::api' do
         :workers                  => '5',
         :show_image_direct_url    => true,
         :show_multiple_locations  => true,
+        :filesystem_store_metadata_file => '/etc/glance/glance-metadata-file.conf',
+        :filesystem_store_file_perm => '0644',
         :location_strategy        => 'store_type',
         :delayed_delete           => 'true',
         :scrub_time               => '10',
         :image_cache_dir          => '/tmp/glance',
+        :image_import_plugins     => 'image_conversion',
+        :image_conversion_output_format => 'raw',
+        :inject_metadata_properties => 'key:val',
+        :ignore_user_roles        => 'admin',
         :enabled_import_methods   => 'glance-direct,web-download',
         :node_staging_uri         => '/tmp/staging',
         :image_member_quota       => '128',
@@ -96,7 +103,6 @@ describe 'glance::api' do
 
         it { is_expected.to contain_class 'glance' }
         it { is_expected.to contain_class 'glance::policy' }
-        it { is_expected.to contain_class 'glance::api::logging' }
         it { is_expected.to contain_class 'glance::api::db' }
 
         it 'is_expected.to not sync the db if sync_db is set to false' do
@@ -119,7 +125,6 @@ describe 'glance::api' do
 
         it 'is_expected.to lay down default api config' do
           [
-            'use_stderr',
             'bind_host',
             'bind_port',
             'registry_host',
@@ -148,6 +153,19 @@ describe 'glance::api' do
                            "[%s]" % param_hash[:enabled_import_methods])
         end
 
+        it 'is_expected.to lay down default image_import_plugins config' do
+          # Verify brackets "[]" are added to satisfy the ListOpt syntax.
+          is_expected.to contain_glance_image_import_config("image_import_opts/image_import_plugins").with_value(
+                           "[%s]" % param_hash[:image_import_plugins])
+        end
+
+
+        it 'is_expected.to lay down default image_conversion & inject_metadata image_import config' do
+          is_expected.to contain_glance_image_import_config("image_conversion/output_format").with_value(param_hash[:image_conversion_output_format])
+          is_expected.to contain_glance_image_import_config("inject_metadata_properties/inject").with_value(param_hash[:inject_metadata_properties])
+          is_expected.to contain_glance_image_import_config("inject_metadata_properties/ignore_user_roles").with_value(param_hash[:ignore_user_roles])
+        end
+
         it 'is_expected.to lay down default cache config' do
           [
             'registry_host',
@@ -168,6 +186,15 @@ describe 'glance::api' do
           end
         end
 
+        it 'is_expected.to lay down default glance_store api config' do
+          [
+            'filesystem_store_metadata_file',
+            'filesystem_store_file_perm',
+          ].each do |config|
+            is_expected.to contain_glance_api_config("glance_store/#{config}").with_value(param_hash[config.intern])
+          end
+        end
+
         it 'is_expected.to lay down default task & taskflow_executor config' do
           is_expected.to contain_glance_api_config('task/task_time_to_live').with_value(param_hash[:task_time_to_live])
           is_expected.to contain_glance_api_config('task/task_executor').with_value(param_hash[:task_executor])
@@ -247,7 +274,7 @@ describe 'glance::api' do
         end
 
         it { expect { is_expected.to contain_glance_api_config('filter:paste_deploy/flavor') }.to\
-          raise_error(Puppet::Error, /validate_re\(\): .* does not match/) }
+          raise_error(Puppet::Error) }
       end
     end
 
@@ -444,7 +471,7 @@ describe 'glance::api' do
 
   describe 'on unknown platforms' do
     let :facts do
-      OSDefaults.get_facts({ :osfamily => 'unknown' })
+      OSDefaults.get_facts({ :osfamily => 'unknown', :os => { :family => 'unknown', :release => { :major => '1'}}})
     end
     let(:params) { default_params }
 
