@@ -1,10 +1,11 @@
 require 'spec_helper'
 
 describe 'glance::registry::db' do
-
   shared_examples 'glance::registry::db' do
     context 'with default parameters' do
-      it { is_expected.to contain_oslo__db('glance_registry_config').with(
+      it { should contain_class('glance::deps') }
+
+      it { should contain_oslo__db('glance_registry_config').with(
         :db_max_retries => '<SERVICE DEFAULT>',
         :connection     => 'sqlite:///var/lib/glance/glance.sqlite',
         :idle_timeout   => '<SERVICE DEFAULT>',
@@ -19,7 +20,8 @@ describe 'glance::registry::db' do
 
     context 'with specific parameters' do
       let :params do
-        { :database_db_max_retries => '-1',
+        {
+          :database_db_max_retries => '-1',
           :database_connection     => 'mysql+pymysql://glance_registry:glance@localhost/glance',
           :database_idle_timeout   => '3601',
           :database_min_pool_size  => '2',
@@ -31,7 +33,9 @@ describe 'glance::registry::db' do
         }
       end
 
-      it { is_expected.to contain_oslo__db('glance_registry_config').with(
+      it { should contain_class('glance::deps') }
+
+      it { should contain_oslo__db('glance_registry_config').with(
         :db_max_retries => '-1',
         :connection     => 'mysql+pymysql://glance_registry:glance@localhost/glance',
         :idle_timeout   => '3601',
@@ -43,63 +47,17 @@ describe 'glance::registry::db' do
         :pool_timeout   => '21',
       )}
     end
-
-    context 'with MySQL-python library as backend package' do
-      let :params do
-        { :database_connection => 'mysql+pymysql://glance_registry:glance@localhost/glance' }
-      end
-
-      it { is_expected.to contain_package('python-mysqldb').with(:ensure => 'present') }
-    end
-
-    context 'with incorrect pymysql database_connection string' do
-      let :params do
-        { :database_connection => 'foo+pymysql://glance_registry:glance@localhost/glance', }
-      end
-
-      it_raises 'a Puppet::Error', /validate_re/
-    end
-
   end
 
-  shared_examples_for 'glance::registry::db Debian' do
-    context 'using pymysql driver' do
-      let :params do
-        { :database_connection => 'mysql+pymysql://glance_registry:glance@localhost/glance', }
-      end
-
-      it 'install the proper backend package' do
-        is_expected.to contain_package('python-pymysql').with(
-          :ensure => 'present',
-          :name   => 'python-pymysql',
-          :tag    => 'openstack'
-        )
-      end
-    end
-  end
-
-  shared_examples_for 'glance::registry::db RedHat' do
-    context 'using pymysql driver' do
-      let :params do
-        { :database_connection => 'mysql+pymysql://glance_registry:glance@localhost/glance', }
-      end
-
-    end
-  end
-
-
   on_supported_os({
-    :supported_os   => OSDefaults.get_supported_os
+    :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      it_configures 'glance::registry::db'
-      it_configures "glance::registry::db #{facts[:osfamily]}"
+      it_behaves_like 'glance::registry::db'
     end
   end
-
 end
-
