@@ -10,7 +10,7 @@ describe provider_class do
     ENV['OS_USERNAME']     = 'test'
     ENV['OS_PASSWORD']     = 'abc123'
     ENV['OS_PROJECT_NAME'] = 'test'
-    ENV['OS_AUTH_URL']     = 'http://127.0.0.1:35357/v2.0'
+    ENV['OS_AUTH_URL']     = 'http://127.0.0.1:5000/v3'
   end
 
   describe 'when managing an image' do
@@ -22,7 +22,7 @@ describe provider_class do
         :is_public        => 'yes',
         :container_format => 'bare',
         :disk_format      => 'qcow2',
-        :source           => 'http://example.com/image1.img',
+        :source           => '/var/tmp/image1.img',
         :min_ram          => 1024,
         :min_disk         => 1024,
       }
@@ -40,7 +40,7 @@ describe provider_class do
       describe '#create' do
         it 'creates an image' do
           provider.class.stubs(:openstack)
-                        .with('image', 'create', '--format', 'shell', ['image1', '--public', '--container-format=bare', '--disk-format=qcow2', '--min-disk=1024', '--min-ram=1024', '--copy-from=http://example.com/image1.img' ])
+                        .with('image', 'create', '--format', 'shell', ['image1', '--public', '--container-format=bare', '--disk-format=qcow2', '--min-disk=1024', '--min-ram=1024', '--file=/var/tmp/image1.img'])
                         .returns('checksum="ee1eca47dc88f4879d8a229cc70a07c6"
 container_format="bare"
 created_at="2016-03-29T20:52:24Z"
@@ -92,12 +92,12 @@ deleted="False"
 deleted_at="None"
 disk_format="qcow2"
 id="5345b502-efe4-4852-a45d-edaba3a3acc6"
-is_public="True"
+visibility="public"
 min_disk="1024"
 min_ram="1024"
 name="image1"
 owner="None"
-properties="{}"
+properties="os_hash_algo=\'abc123\', os_hash_value=\'test123\', os_hidden=\'true\'"
 protected="False"
 size="1270"
 status="active"
@@ -150,7 +150,7 @@ min_disk="1024"
 min_ram="1024"
 name="image1"
 owner="5a9e521e17014804ab8b4e8b3de488a4"
-properties="something=\'what\', vmware_disktype=\'sparse\'"
+properties="something=\'what\', vmware_disktype=\'sparse\', os_hash_algo=\'abc123\', os_hash_value=\'test123\', os_hidden=\'true\'"
 protected="False"
 schema="/v2/schemas/image"
 size="13287936"
@@ -182,12 +182,12 @@ deleted="False"
 deleted_at="None"
 disk_format="qcow2"
 id="5345b502-efe4-4852-a45d-edaba3a3acc6"
-is_public="True"
+visibility="public"
 min_disk="1024"
 min_ram="1024"
 name="image1"
 owner="None"
-properties="something=\'what\', vmware_disktype=\'sparse\'"
+properties="something=\'what\', vmware_disktype=\'sparse\', os_hash_algo=\'abc123\', os_hash_value=\'test123\', os_hidden=\'true\'"
 protected="False"
 size="1270"
 status="active"
@@ -196,6 +196,7 @@ virtual_size="None"
 ')
         instances = provider_class.instances
         expect(instances.count).to eq(1)
+        expect(instances[0].properties).to eq({ 'something' => 'what', 'vmware_disktype' => 'sparse' })
       end
     end
 
@@ -238,7 +239,7 @@ min_disk="0"
 min_ram="0"
 name="image1"
 owner="5a9e521e17014804ab8b4e8b3de488a4"
-properties="{}"
+properties="os_hash_algo=\'abc123\', os_hash_value=\'test123\', os_hidden=\'true\'"
 protected="False"
 schema="/v2/schemas/image"
 size="13287936"
@@ -272,10 +273,10 @@ disk_format="qcow2"
 id="2b4be0b8-aec0-43af-a404-33c3335a0b3f"
 min_disk="0"
 min_ram="0"
-is_public="True"
+visibility="public"
 name="image1"
 owner="None"
-properties="{}"
+properties="os_hash_algo=\'abc123\', os_hash_value=\'test123\', os_hidden=\'true\'"
 protected="False"
 size="1270"
 status="active"
@@ -289,4 +290,90 @@ virtual_size="None"
 
   end
 
+  describe 'when creating image with tag' do
+
+    let(:tenant_attrs) do
+      {
+        :ensure           => 'present',
+        :name             => 'image1',
+        :is_public        => 'yes',
+        :container_format => 'bare',
+        :disk_format      => 'qcow2',
+        :source           => '/var/tmp/image1.img',
+        :image_tag        => 'testtag',
+      }
+    end
+
+    let(:resource) do
+      Puppet::Type::Glance_image.new(tenant_attrs)
+    end
+
+    let(:provider) do
+      provider_class.new(resource)
+    end
+
+    it_behaves_like 'authenticated with environment variables' do
+      describe '#create' do
+        it 'creates an image' do
+          provider.class.stubs(:openstack)
+                        .with('image', 'create', '--format', 'shell', ['image1', '--public', '--container-format=bare', '--disk-format=qcow2', '--tag=testtag', '--file=/var/tmp/image1.img' ])
+                        .returns('checksum="ee1eca47dc88f4879d8a229cc70a07c6"
+container_format="bare"
+created_at="2016-03-29T20:52:24Z"
+disk_format="qcow2"
+file="/v2/images/8801c5b0-c505-4a15-8ca3-1d2383f8c015/file"
+id="8801c5b0-c505-4a15-8ca3-1d2383f8c015"
+name="image1"
+owner="5a9e521e17014804ab8b4e8b3de488a4"
+tag="testtag"
+protected="False"
+schema="/v2/schemas/image"
+size="13287936"
+status="active"
+tags=""
+updated_at="2016-03-29T20:52:40Z"
+virtual_size="None"
+visibility="public"
+')
+          provider.create
+          expect(provider.exists?).to be_truthy
+        end
+      end
+    end
+
+    describe '.instances' do
+      it 'finds every image' do
+        provider.class.stubs(:openstack)
+                      .with('image', 'list', '--quiet', '--format', 'csv', '--long')
+                      .returns('"ID","Name","Disk Format","Container Format","Size","Status","Tags"
+"5345b502-efe4-4852-a45d-edaba3a3acc6","image1","raw","bare",1270,"active","testtag"
+')
+        provider.class.stubs(:openstack)
+                      .with('image', 'show', '--format', 'shell', '5345b502-efe4-4852-a45d-edaba3a3acc6')
+                      .returns('checksum="09b9c392dc1f6e914cea287cb6be34b0"
+container_format="bare"
+created_at="2015-04-08T18:28:01"
+deleted="False"
+deleted_at="None"
+disk_format="qcow2"
+id="5345b502-efe4-4852-a45d-edaba3a3acc6"
+visibility="public"
+name="image1"
+owner="None"
+tag="testtag"
+tags=""
+protected="False"
+size="1270"
+status="active"
+updated_at="2015-04-10T18:18:18"
+virtual_size="None"
+')
+        instances = provider_class.instances
+        expect(instances.count).to eq(1)
+#        expect(instances[0].image_tag).to eq('testtag')
+      end
+    end
+
+  end
+
 end
